@@ -34,9 +34,9 @@ GeneralOptionsPage::GeneralOptionsPage(QWidget *parent) :
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
-    // copy save path to clipboard
+    // copy file location to clipboard after saving
 
-    mCopyPathToClipboard = new QCheckBox(i18n("Copy save location to the clipboard"), this);
+    mCopyPathToClipboard = new QCheckBox(i18n("Copy file location to clipboard after saving"), this);
     connect(mCopyPathToClipboard, &QCheckBox::toggled, this, &GeneralOptionsPage::markDirty);
     mainLayout->addWidget(mCopyPathToClipboard, 1);
 
@@ -57,10 +57,16 @@ GeneralOptionsPage::GeneralOptionsPage(QWidget *parent) :
     mRememberRect = new QCheckBox(i18n("Remember selected area"), this);
     connect(mRememberRect, &QCheckBox::toggled, this, &GeneralOptionsPage::markDirty);
 
+    // show magnifier
+
+    mShowMagnifier = new QCheckBox(i18n("Show magnifier"), this);
+    connect(mShowMagnifier, &QCheckBox::toggled, this, &GeneralOptionsPage::markDirty);
+
     QVBoxLayout *rrCLayout = new QVBoxLayout;
 //     rrCLayout->setContentsMargins(15, 10, 0, 10);
     rrCLayout->addWidget(mUseLightBackground);
     rrCLayout->addWidget(mRememberRect);
+    rrCLayout->addWidget(mShowMagnifier);
     rrLayout->addLayout(rrCLayout);
     mainLayout->addWidget(rrGroup, 1);
 
@@ -86,6 +92,7 @@ void GeneralOptionsPage::saveChanges()
 
     cfgManager->setUseLightRegionMaskColour(mUseLightBackground->checkState() == Qt::Checked);
     cfgManager->setRememberLastRectangularRegion(mRememberRect->checkState() == Qt::Checked);
+    cfgManager->setShowMagnifierChecked(mShowMagnifier->checkState() == Qt::Checked);
     cfgManager->setCopySaveLocationToClipboard(mCopyPathToClipboard->checkState() == Qt::Checked);
 
     mChangesMade = false;
@@ -97,6 +104,7 @@ void GeneralOptionsPage::resetChanges()
 
     mUseLightBackground->setChecked(cfgManager->useLightRegionMaskColour());
     mRememberRect->setChecked(cfgManager->rememberLastRectangularRegion());
+    mShowMagnifier->setChecked(cfgManager->showMagnifierChecked());
     mCopyPathToClipboard->setChecked(cfgManager->copySaveLocationToClipboard());
 
     mChangesMade = false;
