@@ -19,21 +19,17 @@
 
 #include "QuickEditor.h"
 
-#include <QSize>
-#include <QPixmap>
-#include <QSharedPointer>
-#include <QMetaObject>
+#include "SpectacleConfig.h"
 
+#include <KDeclarative/KDeclarative>
+#include <kdeclarative_version.h>
+
+#include <QPixmap>
 #include <QQuickImageProvider>
 #include <QQuickItem>
 #include <QQuickItemGrabResult>
 #include <QQuickView>
-#include <QQmlEngine>
-
-#include <KLocalizedString>
-#include <KDeclarative/KDeclarative>
-
-#include "SpectacleConfig.h"
+#include <QSize>
 
 struct QuickEditor::ImageStore : public QQuickImageProvider
 {
@@ -79,11 +75,19 @@ QuickEditor::QuickEditor(const QPixmap &pixmap, QObject *parent) :
     d->mQmlEngine = new QQmlEngine();
     d->mDecl = new KDeclarative::KDeclarative;
     d->mDecl->setDeclarativeEngine(d->mQmlEngine);
+
+#if KDECLARATIVE_VERSION >= QT_VERSION_CHECK(5, 45, 0)
+    d->mDecl->setupEngine(d->mQmlEngine);
+    d->mDecl->setupContext();
+#else
     d->mDecl->setupBindings();
+#endif
+
     d->mQmlEngine->addImageProvider(QStringLiteral("snapshot"), mImageStore);
 
-    d->mQuickView = new QQuickView(d->mQmlEngine, 0);
-    d->mQuickView->setSource(QUrl("qrc:///QuickEditor/EditorRoot.qml"));
+    d->mQuickView = new QQuickView(d->mQmlEngine, nullptr);
+    d->mQuickView->setClearBeforeRendering(false);
+    d->mQuickView->setSource(QUrl(QStringLiteral("qrc:///QuickEditor/EditorRoot.qml")));
 
     d->mQuickView->setFlags(Qt::BypassWindowManagerHint | Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint | Qt::Tool);
     d->mQuickView->setGeometry(0, 0, pixmap.width(), pixmap.height());
@@ -110,9 +114,10 @@ QuickEditor::QuickEditor(const QPixmap &pixmap, QObject *parent) :
         }
     }
 
+    rootItem->setProperty("showMagnifier", config->showMagnifierChecked());
+
     if (config->useLightRegionMaskColour()) {
-        rootItem->setProperty("maskColour", QColor(255, 255, 255, 192));
-        rootItem->setProperty("strokeColour", QColor(96, 96, 96, 255));
+        rootItem->setProperty("maskColour", QColor(255, 255, 255, 100));
     }
 }
 
