@@ -28,7 +28,7 @@ class QuickEditor : public QObject
 
     public:
 
-    explicit QuickEditor(const QPixmap &pixmap, QObject *parent = 0);
+    explicit QuickEditor(const QPixmap &pixmap, QObject *parent = nullptr);
     virtual ~QuickEditor();
 
     signals:
@@ -39,7 +39,6 @@ class QuickEditor : public QObject
     private slots:
 
     void acceptImageHandler(int x, int y, int width, int height);
-    void grabReadyHandler();
 
     private:
 
